Module config

Module config 

Structs

AppConfig
AppRegistry
BehaviorConfig
CloudConfig
ConfigPaths
ProviderConfig
ResolvedProvider
ResolvedProviderSummary
TargetConfig
ToolingConfig

Enums

ProviderKind

Functions

active_app_path
app_name_from_dir
delete_secret
find_app_dir_from
Walk upward from start looking for a .appctl directory.
find_registered_app_name
load_secret
normalize_app_dir
read_json
registry_default_looks_like_os_username
true when the default registry label would be the home directory basename (e.g. ~/.appctlesubalew), which is often a poor global name in appctl app list.
save_secret
write_json